@@ -23,10 +23,8 @@
     //missing_docs
 )]
 #![allow(unused_variables, dead_code)]
-// TODO: when we will be ready for the release #![deny(missing_docs, dead_code)]
-// This is required because of incomplete rust async implementation and can be
-// removed after async trait feature completion in rust compiler
-#![cfg_attr(feature = "async", allow(where_clauses_object_safety))]
+#![allow(clippy::needless_borrow)] // Caused by a bug in amplify_derive::Display
+                                   // TODO: when we will be ready for the release #![deny(missing_docs, dead_code)]
 
 #[macro_use]
 extern crate amplify;
@@ -89,7 +87,7 @@ pub trait UrlString {
     fn url_scheme(&self) -> &'static str;
 
     /// Returns URL string representation for a given node or socket address. If
-    /// you need full URL address, please use [`Url::from()`] instead (this
+    /// you need full URL address, please use `Url::from()` instead (this
     /// will require `url` feature for LNP/BP Core Library).
     fn to_url_string(&self) -> String;
 }
@@ -97,8 +95,9 @@ pub trait UrlString {
 pub use inet2_addr::NoOnionSupportError;
 
 /// Error extracting transport-level address types ([`FramingProtocol`],
-/// [`LocalAddr`], [`RemoteAddr`]) and session-level node types ([`NodeAddr`],
-/// [`RemoteNodeAddr`]) from string, URLs and other data types
+/// [`LocalSocketAddr`], [`RemoteSocketAddr`]) and session-level node types
+/// ([`NodeAddr`], [`LocalNode`], [`RemoteNodeAddr`]) from string, URLs and
+/// other data types
 #[derive(Clone, PartialEq, Eq, Debug, Display, Error, From)]
 #[display(doc_comments)]
 pub enum AddrError {
